@@ -13,14 +13,17 @@ from .journals import JournalLeaderEntryInlineAdmin
 @admin.register(TimesheetEntry)
 class TimesheetEntryAdmin(AdminExportMixin, admin.ModelAdmin):
     form = TimesheetEntryAdminForm
-    date_hierarchy = 'date'
-    list_display = ('timesheet', 'date', 'start', 'end', 'duration', 'entry_type')
-    list_filter = ('entry_type', ('timesheet__leader', LeaderListFilter))
-    ordering = ('-date', '-start',)
+    date_hierarchy = "date"
+    list_display = ("timesheet", "date", "start", "end", "duration", "entry_type")
+    list_filter = ("entry_type", ("timesheet__leader", LeaderListFilter))
+    ordering = (
+        "-date",
+        "-start",
+    )
 
     def get_readonly_fields(self, request, obj=None):
         if obj and obj.timesheet.submitted:
-            return ('timesheet', 'entry_type', 'date', 'start', 'end')
+            return ("timesheet", "entry_type", "date", "start", "end")
         return ()
 
     def has_add_permission(self, request):
@@ -29,7 +32,7 @@ class TimesheetEntryAdmin(AdminExportMixin, admin.ModelAdmin):
     def has_delete_permission(self, request, obj=None):
         if obj and obj.timesheet.submitted:
             return False
-        return super(TimesheetEntryAdmin, self).has_delete_permission(request, obj)
+        return super().has_delete_permission(request, obj)
 
 
 class TimesheetEntryInlineAdmin(admin.TabularInline):
@@ -37,9 +40,10 @@ class TimesheetEntryInlineAdmin(admin.TabularInline):
         class Meta:
             model = TimesheetEntry
             fields = []
+
     model = TimesheetEntry
-    ordering = ('date', 'start')
-    readonly_fields = ('date', 'start', 'end', 'entry_type', 'description_html', 'edit_link')
+    ordering = ("date", "start")
+    readonly_fields = ("date", "start", "end", "entry_type", "description_html", "edit_link")
 
     def has_add_permission(self, request):
         return False
@@ -47,30 +51,32 @@ class TimesheetEntryInlineAdmin(admin.TabularInline):
     def has_delete_permission(self, request, obj=None):
         if obj and obj.submitted:
             return False
-        return super(TimesheetEntryInlineAdmin, self).has_delete_permission(request, obj)
+        return super().has_delete_permission(request, obj)
 
     def description_html(self, obj):
         return obj.description
-    description_html.short_description = _('description')
-    description_html.admin_order_field = 'description'
+
+    description_html.short_description = _("description")
+    description_html.admin_order_field = "description"
     description_html.allow_tags = True
 
     def edit_link(self, obj):
         return '<a href="{url}" title="{title}" target="_blank">{edit}</a>'.format(
-            url=reverse('admin:leprikon_timesheetentry_change', args=[obj.id]),
-            title=_('update entry'),
-            edit=_('edit'),
+            url=reverse("admin:leprikon_timesheetentry_change", args=[obj.id]),
+            title=_("update entry"),
+            edit=_("edit"),
         )
-    edit_link.short_description = ''
+
+    edit_link.short_description = ""
     edit_link.allow_tags = True
 
 
 @admin.register(Timesheet)
 class TimesheetAdmin(AdminExportMixin, admin.ModelAdmin):
-    list_display = ('leader', 'period', 'group_durations', 'submitted', 'paid')
-    list_filter = (('leader', LeaderListFilter), 'period')
+    list_display = ("leader", "period", "group_durations", "submitted", "paid")
+    list_filter = (("leader", LeaderListFilter), "period")
     inlines = (TimesheetEntryInlineAdmin, JournalLeaderEntryInlineAdmin)
-    actions = ('submit', 'set_paid')
+    actions = ("submit", "set_paid")
 
     # do not allow to add timesheets in admin
     # timesheets are created automatically
@@ -79,44 +85,45 @@ class TimesheetAdmin(AdminExportMixin, admin.ModelAdmin):
 
     # do not allow to delete submitted timesheets
     def has_delete_permission(self, request, obj=None):
-        return super().has_delete_permission(request, obj) and (
-            obj is None or not obj.submitted
-        )
+        return super().has_delete_permission(request, obj) and (obj is None or not obj.submitted)
 
     def get_actions(self, request):
-        actions = super(TimesheetAdmin, self).get_actions(request)
-        if 'delete_selected' in actions:
+        actions = super().get_actions(request)
+        if "delete_selected" in actions:
+
             def delete_selected(model_admin, request, queryset):
                 queryset = queryset.filter(submitted=False)
                 return admin.actions.delete_selected(model_admin, request, queryset)
-            actions['delete_selected'] = (
-                delete_selected,
-                *actions['delete_selected'][1:]
-            )
+
+            actions["delete_selected"] = (delete_selected, *actions["delete_selected"][1:])
         return actions
 
     def group_durations(self, obj):
-        return '<br/>'.join(
-            '<b>{name}</b>: {duration}'.format(
+        return "<br/>".join(
+            "<b>{name}</b>: {duration}".format(
                 name=group.name,
                 duration=group.duration,
-            ) for group in obj.groups
+            )
+            for group in obj.groups
         )
+
     group_durations.allow_tags = True
-    group_durations.short_description = _('group durations')
+    group_durations.short_description = _("group durations")
 
     def set_paid(self, request, queryset):
         queryset.update(submitted=True, paid=True)
-        self.message_user(request, _('Selected timesheets where marked as paid.'))
-    set_paid.short_description = _('Mark selected timesheets as paid')
+        self.message_user(request, _("Selected timesheets where marked as paid."))
+
+    set_paid.short_description = _("Mark selected timesheets as paid")
 
     def submit(self, request, queryset):
         queryset.update(submitted=True)
-        self.message_user(request, _('Selected timesheets where submitted.'))
-    submit.short_description = _('Submit selected timesheets')
+        self.message_user(request, _("Selected timesheets where submitted."))
+
+    submit.short_description = _("Submit selected timesheets")
 
 
 @admin.register(TimesheetEntryType)
 class TimesheetEntryTypeAdmin(admin.ModelAdmin):
-    list_display = ('name', 'order')
-    list_editable = ('order',)
+    list_display = ("name", "order")
+    list_editable = ("order",)
