@@ -7,8 +7,8 @@ from .base import LeprikonPluginBase
 
 @plugin_pool.register_plugin
 class LeprikonSchoolYearBlockPlugin(LeprikonPluginBase):
-    name = _('School year block')
+    name = _("School year block")
     model = SchoolYearBlockPlugin
     allow_children = True
-    filter_horizontal = ('school_years',)
-    render_template = 'leprikon/cms/school_year_block.html'
+    filter_horizontal = ("school_years",)
+    render_template = "leprikon/cms/school_year_block.html"
