@@ -852,7 +852,9 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
     participants_list.short_description = _("participants")
 
     def participants_list_html(self):
-        return mark_safe("<br/>".join(map(str, self.all_participants)))
+        if self.all_participants:
+            return mark_safe("<br/>".join(map(str, self.all_participants)))
+        return self.group_members_list_html()
 
     participants_list_html.short_description = _("participants")
 
@@ -1132,16 +1134,18 @@ class SubjectRegistration(PdfExportAndMailMixin, models.Model):
 
         if not self.payment_status.overpaid:
             return
-        remote_accounts = list(
-            self.received_payments.annotate(
+        remote_accounts = set(
+            account
+            for account in self.received_payments.annotate(
                 account=models.F("bankreader_transaction__remote_account_number")
             ).values_list("account", flat=True)
+            if account
         )
-        if len(remote_accounts) == 1 and remote_accounts[0]:
+        if len(remote_accounts) == 1:
             RefundRequest.objects.create(
                 registration=self,
                 requested_by=generated_by,
-                bank_account=BankAccount(remote_accounts[0]),
+                bank_account=BankAccount(remote_accounts.pop()),
             )
 
     def refuse(self, refused_by):
