@@ -1,4 +1,5 @@
 from collections import namedtuple
+from datetime import timedelta
 
 from django.db.models import Sum
 from django.template.response import TemplateResponse
@@ -10,6 +11,7 @@ from ...forms.reports.courses import CoursePaymentsForm, CoursePaymentsStatusFor
 from ...models.agegroup import AgeGroup
 from ...models.citizenship import Citizenship
 from ...models.courses import Course, CourseRegistration
+from ...models.journals import JournalTime
 from ...models.roles import Participant
 from ...models.subjects import SubjectPayment, SubjectRegistrationParticipant, SubjectType
 from ...views.generic import FormView
@@ -35,8 +37,8 @@ class ReportCoursePaymentsView(FormView):
             accounted__gte=context["date_start"],
             accounted__lte=context["date_end"],
         )
-        context["received_payments_sum"] = context["received_payments"].aggregate(sum=Sum("amount"))["sum"]
-        context["returned_payments_sum"] = context["returned_payments"].aggregate(sum=Sum("amount"))["sum"]
+        context["received_payments_sum"] = context["received_payments"].aggregate(sum=Sum("amount"))["sum"] or 0
+        context["returned_payments_sum"] = context["returned_payments"].aggregate(sum=Sum("amount"))["sum"] or 0
         context["sum"] = context["received_payments_sum"] - context["returned_payments_sum"]
         return TemplateResponse(self.request, self.template_name, self.get_context_data(**context))
 
@@ -109,6 +111,7 @@ class ReportCourseStatsView(FormView):
     def form_valid(self, form):
         d = form.cleaned_data["date"]
         paid_only = form.cleaned_data["paid_only"]
+        unique_participants = form.cleaned_data["unique_participants"]
         context = form.cleaned_data
         context["form"] = form
 
@@ -128,7 +131,25 @@ class ReportCourseStatsView(FormView):
             ]
         else:
             participants = list(participants)
+
         context["courses_count"] = len(set(participant.registration.subject_id for participant in participants))
+        delta = sum(
+            (
+                sum(
+                    (jt.delta for jt in JournalTime.objects.filter(journal__participants=participant)),
+                    start=timedelta(0),
+                )
+                for participant in participants
+            ),
+            start=timedelta(0),
+        )
+        context["participant_hours_count"] = delta.days * 24 + delta.seconds / 3600
+
+        if unique_participants:
+            participants_by_name_and_birth_date = {
+                (p.first_name.lower(), p.last_name.lower(), p.birth_date): p for p in participants
+            }
+            participants = list(participants_by_name_and_birth_date.values())
 
         citizenships = list(Citizenship.objects.all())
         context["citizenships"] = citizenships
